package com.bonus.material.basic.mapper;

import java.util.List;
import com.bonus.material.basic.domain.BmNoticeInfo;

/**
 * 短信通知Mapper接口
 * 
 * @author xsheng
 * @date 2024-09-26
 */
public interface BmNoticeInfoMapper 
{
    /**
     * 查询短信通知
     * 
     * @param id 短信通知主键
     * @return 短信通知
     */
    public BmNoticeInfo selectBmNoticeInfoById(Long id);

    /**
     * 查询短信通知列表
     * 
     * @param bmNoticeInfo 短信通知
     * @return 短信通知集合
     */
    public List<BmNoticeInfo> selectBmNoticeInfoList(BmNoticeInfo bmNoticeInfo);

    /**
     * 新增短信通知
     * 
     * @param bmNoticeInfo 短信通知
     * @return 结果
     */
    public int insertBmNoticeInfo(BmNoticeInfo bmNoticeInfo);

    /**
     * 修改短信通知
     * 
     * @param bmNoticeInfo 短信通知
     * @return 结果
     */
    public int updateBmNoticeInfo(BmNoticeInfo bmNoticeInfo);

    /**
     * 删除短信通知
     * 
     * @param id 短信通知主键
     * @return 结果
     */
    public int deleteBmNoticeInfoById(Long id);

    /**
     * 批量删除短信通知
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBmNoticeInfoByIds(Long[] ids);
}
