package com.bonus.material.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.basic.domain.BmNoticeInfo;
import com.bonus.material.basic.service.IBmNoticeInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 短信通知Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "短信通知接口")
@RestController
@RequestMapping("/bm_notice_info")
public class BmNoticeInfoController extends BaseController
{
    @Autowired
    private IBmNoticeInfoService bmNoticeInfoService;

    /**
     * 查询短信通知列表
     */
    @ApiOperation(value = "查询短信通知列表")
    @RequiresPermissions("basic:info:list")
    @GetMapping("/list")
    public TableDataInfo list(BmNoticeInfo bmNoticeInfo)
    {
        startPage();
        List<BmNoticeInfo> list = bmNoticeInfoService.selectBmNoticeInfoList(bmNoticeInfo);
        return getDataTable(list);
    }

    /**
     * 导出短信通知列表
     */
    @ApiOperation(value = "导出短信通知列表")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:info:export")
    @SysLog(title = "短信通知", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出短信通知")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmNoticeInfo bmNoticeInfo)
    {
        List<BmNoticeInfo> list = bmNoticeInfoService.selectBmNoticeInfoList(bmNoticeInfo);
        ExcelUtil<BmNoticeInfo> util = new ExcelUtil<BmNoticeInfo>(BmNoticeInfo.class);
        util.exportExcel(response, list, "短信通知数据");
    }

    /**
     * 获取短信通知详细信息
     */
    @ApiOperation(value = "获取短信通知详细信息")
    @RequiresPermissions("basic:info:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bmNoticeInfoService.selectBmNoticeInfoById(id));
    }

    /**
     * 新增短信通知
     */
    @ApiOperation(value = "新增短信通知")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:info:add")
    @SysLog(title = "短信通知", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增短信通知")
    @PostMapping
    public AjaxResult add(@RequestBody BmNoticeInfo bmNoticeInfo)
    {
        return toAjax(bmNoticeInfoService.insertBmNoticeInfo(bmNoticeInfo));
    }

    /**
     * 修改短信通知
     */
    @ApiOperation(value = "修改短信通知")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:info:edit")
    @SysLog(title = "短信通知", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改短信通知")
    @PutMapping
    public AjaxResult edit(@RequestBody BmNoticeInfo bmNoticeInfo)
    {
        return toAjax(bmNoticeInfoService.updateBmNoticeInfo(bmNoticeInfo));
    }

    /**
     * 删除短信通知
     */
    @ApiOperation(value = "删除短信通知")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:info:remove")
    @SysLog(title = "短信通知", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除短信通知")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bmNoticeInfoService.deleteBmNoticeInfoByIds(ids));
    }
}
